/*
 * Copyright (C) 2002-2005 Stefan Stiller
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package com.kiwisoft.db;

import java.sql.DatabaseMetaData;

import com.intellij.openapi.project.Project;
import com.kiwisoft.utils.PropertyHolder;
import com.kiwisoft.utils.Tristate;

/**
 * @author Stefan Stiller
 * @version $Revision: 1.2 $, $Date: 2005/08/10 18:51:47 $
 */
public class DataType implements PropertyHolder
{
    private static final String NAME="Name";
    private static final String DATA_TYPE="Data Type (java.sql.Types)";
    private static final String PRECISION="Precision";
    private static final String LITERAL_PREFIX="Literal Prefix";
    private static final String LITERAL_SUFFIX="Literal Suffix";
	private static final String CREATE_PARAMS="Create Parameters";
	private static final String NULLABLE="Nullable";
	private static final String CASE_SENSITIVE="Case Sensitive";
	private static final String SEARCHABLE="Searchable";
	private static final String UNSIGNED="Unsigned";
	private static final String FIXED_PRECISION_SCALE="Fixed Precision Scale";
	private static final String AUTO_INCREMENT="Auto Increment";
	private static final String LOCAL_TYPE_NAME="Local Type Name";
	private static final String MINIMUM_SCALE="Minimum Scale";
	private static final String MAXIMUM_SCALE="Maximum Scale";

    private String name;
	private int dataType;
	private long precision;
	private String literalPrefix;
	private String literalSuffix;
	private String createParams;
	private short nullable;
	private boolean caseSensitive;
	private short searchable;
	private boolean unsigned;
	private boolean fixedPrecisionScale;
	private boolean autoIncrement;
	private String localTypeName;
	private short miniumScale;
	private short maximumScale;

	public DataType(String name)
    {
		this.name=name;
	}

	public String getName()
	{
		return name;
	}

	public void setDataType(int type)
	{
		dataType=type;
	}

    public String[] getPropertyNames()
    {
        return new String[]{
            NAME, DATA_TYPE, PRECISION, LITERAL_PREFIX, LITERAL_SUFFIX,
			CREATE_PARAMS, NULLABLE, CASE_SENSITIVE, SEARCHABLE,
			UNSIGNED, FIXED_PRECISION_SCALE, AUTO_INCREMENT,
			LOCAL_TYPE_NAME, MINIMUM_SCALE, MAXIMUM_SCALE
        };
    }

    public Object getProperty(Project project, String propertyName) throws Exception
	{
        if (propertyName==NAME) return name;
        if (propertyName==DATA_TYPE) return DatabaseUtils.getTypeString(dataType)+" ["+dataType+']';
		if (propertyName==PRECISION) return new Long(precision);
		if (propertyName==LITERAL_PREFIX) return literalPrefix;
		if (propertyName==LITERAL_SUFFIX) return literalSuffix;
		if (propertyName==CREATE_PARAMS) return createParams;
		if (propertyName==NULLABLE)
		{
			switch (nullable)
			{
				case DatabaseMetaData.attributeNullable: return Tristate.TRUE;
				case DatabaseMetaData.attributeNoNulls: return Tristate.FALSE;
				case DatabaseMetaData.attributeNullableUnknown: return Tristate.UNDEFINED;
			}
		}
		if (propertyName==CASE_SENSITIVE) return new Boolean(caseSensitive);
		if (propertyName==SEARCHABLE)
		{
			switch (searchable)
			{
				case DatabaseMetaData.typePredNone: return "Not supported";
				case DatabaseMetaData.typePredChar: return "Only supported with WHERE ... LIKE";
				case DatabaseMetaData.typePredBasic: return "Supported except for WHERE ... LIKE";
				case DatabaseMetaData.typeSearchable: return "Fully supported";
			}
		}
		if (propertyName==UNSIGNED) return new Boolean(unsigned);
		if (propertyName==FIXED_PRECISION_SCALE) return new Boolean(fixedPrecisionScale);
		if (propertyName==AUTO_INCREMENT) return new Boolean(autoIncrement);
		if (propertyName==LOCAL_TYPE_NAME) return localTypeName;
		if (propertyName==MINIMUM_SCALE) return new Short(miniumScale);
		if (propertyName==MAXIMUM_SCALE) return new Short(maximumScale);
        return null;
    }

	public void setPrecision(long precision)
	{
		this.precision=precision;
	}

	public void setLiteralPrefix(String value)
	{
		literalPrefix=value;
	}

	public void setLiteralSuffix(String value)
	{
		literalSuffix=value;
	}

	public void setCreateParams(String value)
	{
		createParams=value;
	}

	public void setNullable(short value)
	{
		nullable=value;
	}

	public void setCaseSensitive(boolean value)
	{
		caseSensitive=value;
	}

	public void setSearchable(short value)
	{
		searchable=value;
	}

	public void setUnsigned(boolean value)
	{
		unsigned=value;
	}

	public void setFixedPrecisionScale(boolean value)
	{
		fixedPrecisionScale=value;
	}

	public void setAutoIncrement(boolean value)
	{
		autoIncrement=value;
	}

	public void setLocalTypeName(String value)
	{
		localTypeName=value;
	}

	public void setMinimumScale(short value)
	{
		miniumScale=value;
	}

	public void setMaximumScale(short value)
	{
		maximumScale=value;
	}
}
