/*
 * Copyright (C) 2002-2005 Stefan Stiller
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package com.kiwisoft.db;

import java.sql.DatabaseMetaData;

import com.kiwisoft.utils.PropertyHolder;
import com.intellij.openapi.project.Project;

/**
 * @author Stefan Stiller
 * @version $Revision: 1.3 $, $Date: 2005/08/10 18:51:48 $
 */
public class Index implements PropertyHolder
{
	private DatabaseTable table;

	private static final String NAME="Name";
	private static final String NON_UNIQUE="Non Unique";
	private static final String TYPE="Type";
	private static final String COLUMN_NAME="Column";
	private static final String SORTING="Sorting";
	private static final String CARDINALITY="Cardinality";
	private static final String PAGES="Pages";
	private static final String FILTER_CONDITION="Filter Condition";

	private String name;
	private boolean nonUnique;
	private short type;
	private String columnName;
	private String sorting;
	private int cardinality;
	private int pages;
	private String filterCondition;

	public Index(DatabaseTable table, String indexName)
	{
		this.table=table;
		this.name=indexName;
	}

	public DatabaseTable getTable()
	{
		return table;
	}

	public String getName()
	{
		return name;
	}

	public String[] getPropertyNames()
	{
		return new String[]{NAME, NON_UNIQUE, TYPE, COLUMN_NAME, SORTING, CARDINALITY, PAGES, FILTER_CONDITION};
	}

	public Object getProperty(Project project, String propertyName)
	{
		if (propertyName==NAME) return name;
		if (propertyName==NON_UNIQUE) return new Boolean(nonUnique);
		if (propertyName==TYPE) return getTypeString();
		if (propertyName==COLUMN_NAME) return columnName;
		if (propertyName==SORTING)
		{
			if ("A".equals(sorting)) return "Ascending";
			if ("D".equals(sorting)) return "Descending";
			return sorting;
		}
		if (propertyName==CARDINALITY) return new Integer(cardinality);
		if (propertyName==PAGES) return new Integer(pages);
		if (propertyName==FILTER_CONDITION) return filterCondition;
		return null;
	}

	public String getTypeString()
	{
		switch (type)
		{
			case DatabaseMetaData.tableIndexClustered:
				return "Clustered Index";
			case DatabaseMetaData.tableIndexHashed:
				return "Hashed Index";
			case DatabaseMetaData.tableIndexOther:
				return "Unknown Index Type";
			case DatabaseMetaData.tableIndexStatistic:
				return "Table Statistics";
		}
		return null;
	}
	public void setNonUnique(boolean value)
	{
		nonUnique=value;
	}

	public void setType(short value)
	{
		type=value;
	}

	public void setColumnName(String value)
	{
		columnName=value;
	}

	public void setSorting(String value)
	{
		sorting=value;
	}

	public void setCardinality(int value)
	{
		cardinality=value;
	}

	public void setPages(int value)
	{
		pages=value;
	}

	public void setFilterCondition(String value)
	{
		filterCondition=value;
	}
}
