/*
 * Copyright (C) 2002-2005 Stefan Stiller
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package com.kiwisoft.db.driver;

import java.io.File;
import java.io.FilenameFilter;
import java.net.MalformedURLException;
import java.net.URL;
import java.net.URLClassLoader;
import java.util.*;

import com.kiwisoft.utils.StringUtils;

/**
 * @author Stefan Stiller
 * @version $Revision: 1.4 $, $Date: 2005/08/10 18:51:01 $
 */
public class DatabaseDriverManager
{
	private static ClassLoader classLoader=DatabaseDriverManager.class.getClassLoader();
	private static String driversPath;

	public static ClassLoader getClassLoader()
	{
		return classLoader;
	}

	public static String getDriversPath()
	{
		return driversPath;
	}

	public static void setDriversPath(String aPath)
	{
		if (!StringUtils.equal(driversPath, aPath))
		{
			driversPath=aPath;
			List urls=new ArrayList();
			File path=new File(driversPath);
			if (path.exists() && path.isDirectory())
			{
				File[] files=path.listFiles(new FilenameFilter()
				{
					public boolean accept(File dir, String name)
					{
						name=name.toLowerCase();
						return name.endsWith(".jar") || name.endsWith(".zip");
					}
				});
				for (int i=0; i<files.length; i++)
				{
					File file=files[i];
					try
					{
						urls.add(file.toURL());
					}
					catch (MalformedURLException e)
					{
						e.printStackTrace();
					}
				}
			}
			if (!urls.isEmpty())
				classLoader=new URLClassLoader((URL[])urls.toArray(new URL[0]), DatabaseDriverManager.class.getClassLoader());
			if (instance!=null)
			{
				for (Iterator it=instance.drivers.values().iterator(); it.hasNext();)
				{
					DatabaseDriver driver=(DatabaseDriver)it.next();
					driver.loadDriver();
				}
			}
		}
	}

	private static DatabaseDriverManager instance;

	public synchronized static DatabaseDriverManager getInstance()
	{
		if (instance==null) instance=new DatabaseDriverManager();
		return instance;
	}

	private Map drivers;

	private DatabaseDriverManager()
	{
		drivers=new HashMap();
		installDriver(new OracleDriver());
		installDriver(new MySQLDriver());
		installDriver(new DefaultDriver());
		installDriver(new JdbcOdbcDriver());
		installDriver(new SybaseDriver());
		installDriver(new MicrosoftSQLServerDriver());
		installDriver(new DataDirectSQLServerDriver());
		installDriver(new FirebirdDriver());
		installDriver(new PostgreSQLDriver());
		installDriver(new AS400Driver());
		installDriver(new InformixDriver());
		installDriver(new HSQLDBDriver());
		installDriver(new DB2Driver());
		installDriver(new JtdsSQLServerDriver());
	}

	private void installDriver(DatabaseDriver driver)
	{
		drivers.put(driver.getId(), driver);
	}

	public Collection getAllDrivers()
	{
		return Collections.unmodifiableCollection(drivers.values());
	}

	public DatabaseDriver getDriver(String driverName)
	{
		return (DatabaseDriver)drivers.get(driverName);
	}
}

