package com.kiwisoft.db.sql;

import java.util.List;
import java.util.Collections;

/**
 * @author Stefan Stiller
 * @version $Revision: 1.3 $, $Date: 2004/11/16 22:07:00 $
 */
public class DescribeStatement implements SQLStatement
{
	private TokenList tokenList;
	private String schema;
	private NameInfo tableInfo;
	private boolean valid;

	public DescribeStatement(TokenList tokenList)
	{
		this.tokenList=tokenList;
		try
		{
			parse();
		}
		catch (Exception e)
		{
			e.printStackTrace();
			valid=false;
		}
	}

	public boolean isValid()
	{
		return valid;
	}

	private void parse()
	{
		valid=true;
		List tokens=tokenList.trim();
		// <'describe'><space><schemaName><'.'><tableName>
		if (tokens.size()==5)
		{
			assertType(tokens, 1, SpaceToken.class, null);
			assertType(tokens, 2, NameToken.class, null);
			assertType(tokens, 3, SeparatorToken.class, ".");
			assertType(tokens, 4, NameToken.class, null);
			schema=((Token)tokens.get(2)).getText();
			String tableName=((Token)tokens.get(4)).getText();
			tableInfo=new NameInfo(tableName);
			return;
		}
		// <'describe'><space><tableName>
		if (tokens.size()==3)
		{
			assertType(tokens, 1, SpaceToken.class, null);
			assertType(tokens, 2, NameToken.class, null);
			String tableName=((Token)tokens.get(2)).getText();
			tableInfo=new NameInfo(tableName);
			return;
		}
		valid=false;
	}

	private void assertType(List tokens, int offset, Class aClass, String text)
	{
		Token token=(Token)tokens.get(offset);
		if (!aClass.isInstance(token))
			throw new RuntimeException("Invalid statement");
		if (text!=null && !text.equals(token.getNormalizedText()))
			throw new RuntimeException("Invalid statement");
	}

	public String getText()
	{
		return tokenList.getText();
	}

	public String getNormalizedText()
	{
		return tokenList.getNormalizedText();
	}

	public String getSuccessMessage(int updateCount)
	{
		return "Statement executed.";
	}

	public boolean isSimpleSelect()
	{
		return false;
}

	public String getTableName()
	{
		return null;
}

	public String getSchema()
	{
		return schema;
	}

	public NameInfo getTable()
	{
		return tableInfo;
	}
}
