/*
 * Copyright (C) 2002-2005 Stefan Stiller
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package com.kiwisoft.sqlPlugin.settings;

import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import javax.swing.*;
import javax.swing.border.EtchedBorder;
import javax.swing.border.TitledBorder;

import com.intellij.openapi.project.Project;

import com.kiwisoft.sqlPlugin.CommonConfiguration;
import com.kiwisoft.sqlPlugin.config.SQLPluginAppConfig;
import com.kiwisoft.utils.Encoder;
import com.kiwisoft.utils.gui.lookup.DialogLookupField;
import com.kiwisoft.utils.gui.lookup.FileLookup;

/**
 * @author Stefan Stiller
 * @version $Revision: 1.3 $, $Date: 2005/08/10 18:54:32 $
 */
public class MiscPropertiesPanel extends JPanel
{
	private Project project;

	private JRadioButton rbSavePasswordsNot;
	private JRadioButton rbSavePasswordsUnencoded;
	private JRadioButton rbSavePasswordsEncoded;
	private JCheckBox cbConfirmCommit;
	private JCheckBox cbConfirmRollback;
	private JCheckBox cbConfirmDisconnect;
	private JCheckBox cbConnections;
	private DialogLookupField tfDrivers;

	public MiscPropertiesPanel(Project project)
	{
		this.project=project;
		initializeComponents();
		installListeners();
		initializeData();
	}

	private void initializeData()
	{
		CommonConfiguration configuration=CommonConfiguration.getInstance(project);
		cbConfirmCommit.setSelected(!Boolean.TRUE.equals(configuration.getConfirmation(CommonConfiguration.CONFIRM_COMMIT)));
		cbConfirmRollback.setSelected(!Boolean.TRUE.equals(configuration.getConfirmation(CommonConfiguration.CONFIRM_ROLLBACK)));
		cbConfirmDisconnect.setSelected(!Boolean.TRUE.equals(configuration.getConfirmation(CommonConfiguration.CONFIRM_DISCONNECT)));
		if (configuration.isSavePasswords())
		{
			if (configuration.isEncodePasswords()) rbSavePasswordsEncoded.setSelected(true);
			else rbSavePasswordsUnencoded.setSelected(true);
		}
		else rbSavePasswordsNot.setSelected(true);
		rbSavePasswordsEncoded.setEnabled(Encoder.isAvailable());

		SQLPluginAppConfig appConfig=SQLPluginAppConfig.getInstance();
		tfDrivers.setText(appConfig.getDriversPath());
		cbConnections.setSelected(appConfig.isKeepConnectionOpen());
	}

	private void initializeComponents()
	{
		ButtonGroup buttonGroup=new ButtonGroup();
		buttonGroup.add(rbSavePasswordsNot=new JRadioButton("Don't save"));
		buttonGroup.add(rbSavePasswordsEncoded=new JRadioButton("Save encrypted"));
		buttonGroup.add(rbSavePasswordsUnencoded=new JRadioButton("Save as free text"));

		cbConfirmCommit=new JCheckBox("Confirm 'Commit'");
		cbConfirmRollback=new JCheckBox("Confirm 'Rollback'");
		cbConfirmDisconnect=new JCheckBox("Confirm 'Close Connections'");

		tfDrivers=new DialogLookupField(new FileLookup(JFileChooser.DIRECTORIES_ONLY, true));
		cbConnections=new JCheckBox("Don't close with tool window");

		JPanel pnlSecurity=new JPanel();
		int row=0;
		pnlSecurity.setLayout(new GridBagLayout());
		pnlSecurity.setBorder(new TitledBorder(new EtchedBorder(), "Security"));
		pnlSecurity.add(new JLabel("Save passwords in workspace:"),
				new GridBagConstraints(0, row++, 1, 1, 0.0, 0.0, GridBagConstraints.WEST, GridBagConstraints.NONE, new Insets(4, 4, 4, 4), 0, 0));
		pnlSecurity.add(rbSavePasswordsNot,
				new GridBagConstraints(0, row++, 1, 1, 0.0, 0.0, GridBagConstraints.WEST, GridBagConstraints.NONE, new Insets(0, 24, 4, 4), 0, 0));
		pnlSecurity.add(rbSavePasswordsEncoded,
				new GridBagConstraints(0, row++, 1, 1, 0.0, 0.0, GridBagConstraints.WEST, GridBagConstraints.NONE, new Insets(0, 24, 4, 4), 0, 0));
		pnlSecurity.add(rbSavePasswordsUnencoded,
				new GridBagConstraints(0, row++, 1, 1, 0.0, 0.0, GridBagConstraints.WEST, GridBagConstraints.NONE, new Insets(0, 24, 4, 4), 0, 0));
		pnlSecurity.add(Box.createGlue(),
				new GridBagConstraints(1, row, 1, 1, 1.0, 0.0, GridBagConstraints.CENTER, GridBagConstraints.NONE, new Insets(0, 0, 0, 0), 0, 0));

		JPanel pnlDrivers=new JPanel();
		row=0;
		pnlDrivers.setLayout(new GridBagLayout());
		pnlDrivers.setBorder(new TitledBorder(new EtchedBorder(), "Drivers"));
		pnlDrivers.add(new JLabel("Alternative Location:"),
				new GridBagConstraints(0, row, 1, 1, 0.0, 0.0, GridBagConstraints.WEST, GridBagConstraints.NONE, new Insets(4, 4, 4, 4), 0, 0));
		pnlDrivers.add(tfDrivers,
				new GridBagConstraints(1, row, 1, 1, 1.0, 0.0, GridBagConstraints.WEST, GridBagConstraints.HORIZONTAL, new Insets(4, 0, 4, 4), 0, 0));

		JPanel pnlConnections=new JPanel();
		row=0;
		pnlConnections.setLayout(new GridBagLayout());
		pnlConnections.setBorder(new TitledBorder(new EtchedBorder(), "Connections"));
		pnlConnections.add(cbConnections,
				new GridBagConstraints(0, row, 1, 1, 1.0, 0.0, GridBagConstraints.WEST, GridBagConstraints.HORIZONTAL, new Insets(4, 4, 4, 4), 0, 0));

		JPanel pnlConfirmations=new JPanel();
		row=0;
		pnlConfirmations.setLayout(new GridBagLayout());
		pnlConfirmations.setBorder(new TitledBorder(new EtchedBorder(), "Confirmations"));
		pnlConfirmations.add(cbConfirmCommit,
				new GridBagConstraints(0, row, 1, 1, 0.5, 0.0, GridBagConstraints.WEST, GridBagConstraints.NONE, new Insets(4, 4, 4, 4), 0, 0));
		pnlConfirmations.add(cbConfirmDisconnect,
				new GridBagConstraints(1, row++, 1, 1, 0.5, 0.0, GridBagConstraints.WEST, GridBagConstraints.NONE, new Insets(4, 4, 4, 4), 0, 0));
		pnlConfirmations.add(cbConfirmRollback,
				new GridBagConstraints(0, row, 1, 1, 0.5, 0.0, GridBagConstraints.WEST, GridBagConstraints.NONE, new Insets(0, 4, 4, 4), 0, 0));

		setLayout(new GridBagLayout());
		row=0;
		add(pnlDrivers,
				new GridBagConstraints(0, row++, 1, 1, 1.0, 0.0, GridBagConstraints.WEST, GridBagConstraints.HORIZONTAL, new Insets(7, 7, 7, 7), 0, 0));
		add(pnlConnections,
				new GridBagConstraints(0, row++, 1, 1, 1.0, 0.0, GridBagConstraints.WEST, GridBagConstraints.HORIZONTAL, new Insets(0, 7, 7, 7), 0, 0));
		add(pnlSecurity,
				new GridBagConstraints(0, row++, 1, 1, 1.0, 0.0, GridBagConstraints.WEST, GridBagConstraints.HORIZONTAL, new Insets(0, 7, 7, 7), 0, 0));
		add(pnlConfirmations,
				new GridBagConstraints(0, row++, 1, 1, 1.0, 0.0, GridBagConstraints.WEST, GridBagConstraints.HORIZONTAL, new Insets(0, 7, 7, 7), 0, 0));
		add(Box.createGlue(),
				new GridBagConstraints(0, row, 1, 1, 1.0, 1.0, GridBagConstraints.CENTER, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
	}

	private void installListeners()
	{
	}

	private void removeListeners()
	{
	}

	public void removeNotify()
	{
		removeListeners();
	}

	public boolean canApply()
	{
		return true;
	}

	public void apply()
	{
		CommonConfiguration configuration=CommonConfiguration.getInstance(project);
		String driversPath=tfDrivers.getText();

		configuration.setSavePasswords(!rbSavePasswordsNot.isSelected());
		configuration.setEncodePasswords(rbSavePasswordsEncoded.isSelected());
		configuration.setConfirmation(CommonConfiguration.CONFIRM_COMMIT, new Boolean(!cbConfirmCommit.isSelected()));
		configuration.setConfirmation(CommonConfiguration.CONFIRM_ROLLBACK, new Boolean(!cbConfirmRollback.isSelected()));
		configuration.setConfirmation(CommonConfiguration.CONFIRM_DISCONNECT, new Boolean(!cbConfirmDisconnect.isSelected()));

		SQLPluginAppConfig appConfig=SQLPluginAppConfig.getInstance();
		appConfig.setDriversPath(driversPath);
		appConfig.setKeepConnectionOpen(cbConnections.isSelected());
	}
}
