/*
 * Copyright (C) 2002-2005 Stefan Stiller
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package com.kiwisoft.utils;

import java.text.DateFormat;
import java.text.ParseException;
import java.util.Date;
import java.util.Calendar;

/**
 * @author Stefan Stiller
 * @version $Revision: 1.5 $, $Date: 2005/08/10 18:50:21 $
 */
public class DateUtils
{
	public final static long SECOND=1000;
	public final static long MINUTE=60*SECOND;
	public final static long HOUR=60*MINUTE;
	public final static long DAY=24*HOUR;
	public final static long WEEK=7*DAY;

	private static DateFormat[] dateFormats=
			{
				DateFormat.getDateTimeInstance(DateFormat.SHORT, DateFormat.SHORT),
				DateFormat.getDateInstance(DateFormat.SHORT),
				DateFormat.getDateTimeInstance(DateFormat.MEDIUM, DateFormat.MEDIUM),
				DateFormat.getDateInstance(DateFormat.MEDIUM),
				DateFormat.getDateInstance(DateFormat.LONG),
				DateFormat.getDateTimeInstance(DateFormat.LONG, DateFormat.LONG),
				DateFormat.getDateInstance(DateFormat.FULL),
				DateFormat.getDateTimeInstance(DateFormat.FULL, DateFormat.FULL),
			};

	private DateUtils()
	{
	}

	public static boolean isToday(Calendar date)
	{
		Calendar now=Calendar.getInstance();
		if (date.get(Calendar.DAY_OF_YEAR)!=now.get(Calendar.DAY_OF_YEAR)) return false;
		return date.get(Calendar.YEAR)==now.get(Calendar.YEAR);
	}

	public static boolean isWeekend(Calendar date)
	{
		int day=date.get(Calendar.DAY_OF_WEEK);
		return day==Calendar.SUNDAY || day==Calendar.SATURDAY;
	}

	public static Date parseDate(String value)
	{
		if ("sysdate".equalsIgnoreCase(value)) return new Date();
		for (int i=0; i<dateFormats.length; i++)
		{
			DateFormat dateFormat=dateFormats[i];
			try
			{
				return dateFormat.parse(value);
			}
			catch (ParseException e)
			{
			}
		}
		return null;
	}

	/**
	 * Sets the date to the begin of the week.
	 */
	public static void setStartOfWeek(Calendar date)
	{
		date.add(Calendar.DATE,-getDayOfWeek(date));
		date.set(Calendar.HOUR_OF_DAY, 0);
		date.set(Calendar.MINUTE, 0);
		date.set(Calendar.SECOND, 0);
		date.set(Calendar.MILLISECOND, 0);
	}

	/**
	 * Returns the day of week depending if the week starts on sunday or monday.
	 *
	 * @return 0 for the first day of the week and 6 for the last.
	 */
	public static int getDayOfWeek(Calendar date)
	{
		int day=date.get(Calendar.DAY_OF_WEEK);
		if (getFirstDayOfWeek()==Calendar.SUNDAY) return day-1;
		else
		{
			if (day>=Calendar.MONDAY) return day-Calendar.MONDAY;
			else return 6;
		}
	}

	private static int firstDayOfWeek=Calendar.MONDAY;

	public static int getFirstDayOfWeek()
	{
		return firstDayOfWeek;
	}

	/**
	 * Sets the date to the end of the week.
	 */
	public static void setEndOfWeek(Calendar date)
	{
		date.add(Calendar.DATE,7-getDayOfWeek(date));
		date.set(Calendar.HOUR_OF_DAY, 0);
		date.set(Calendar.MINUTE, 0);
		date.set(Calendar.SECOND, 0);
		date.set(Calendar.MILLISECOND, 0);
	}
}
