/*
 * Copyright (C) 2002-2005 Stefan Stiller
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package com.kiwisoft.utils.gui;

import java.awt.*;
import java.awt.event.ActionEvent;
import javax.swing.*;
import javax.swing.event.ListSelectionListener;
import javax.swing.event.ListSelectionEvent;

import com.kiwisoft.utils.idea.DialogStub;
import com.kiwisoft.utils.idea.DialogWrapper;

/**
 * @author Stefan Stiller
 * @version $Revision: 1.2 $, $Date: 2005/08/10 18:55:43 $
 */
public class FontSelectionDialogStub implements DialogStub
{
    private JList lstFonts;
	private JPanel pnlContent;

    private boolean returnValue=false;
	private String font;

    private DialogWrapper dialogWrapper;
	private String currentFont;

	public FontSelectionDialogStub(String currentFont)
    {
		this.currentFont=currentFont;
		initializeComponents();
    }

    public String getTitle()
    {
        return "Select Font";
    }

    public void setDialogWrapper(DialogWrapper dialogWrapper)
    {
        this.dialogWrapper=dialogWrapper;
    }

    public boolean getReturnValue()
    {
        return returnValue;
    }

	public String getFont()
	{
		return font;
	}

    public Action[] getActions()
    {
        return new Action[]{new ApplyAction(), new CancelAction()};
    }

    public JComponent getContentPanel()
    {
        return pnlContent;
    }

    public void dispose()
    {
    }

    private void initializeComponents()
    {
        lstFonts=new JList(GraphicsEnvironment.getLocalGraphicsEnvironment().getAvailableFontFamilyNames());
		lstFonts.addListSelectionListener(new ListSelectionListener()
		{
			public void valueChanged(final ListSelectionEvent e)
			{
				if (!e.getValueIsAdjusting())
				{
					SwingUtilities.invokeLater(new Runnable()
					{
						public void run()
						{
							lstFonts.ensureIndexIsVisible(e.getFirstIndex());
						}
					});
				}
			}
		});

        pnlContent=new JPanel(new GridBagLayout());
        pnlContent.add(new JScrollPane(lstFonts),
            new GridBagConstraints(0, 0, 1, 1, 1.0, 1.0, GridBagConstraints.WEST, GridBagConstraints.HORIZONTAL, new Insets(3, 3, 3, 3), 0, 0));

		if (currentFont!=null) lstFonts.setSelectedValue(currentFont, true);
    }

	public JComponent getPreferredFocusedComponent()
	{
		return lstFonts;
	}

    private class ApplyAction extends AbstractAction
    {
        public ApplyAction()
        {
            super("Ok");
			putValue(DEFAULT_ACTION, Boolean.TRUE);
        }

        public void actionPerformed(ActionEvent e)
        {
            font=(String)lstFonts.getSelectedValue();
			returnValue=true;
            dialogWrapper.dispose();
        }
    }

    private class CancelAction extends AbstractAction
    {
        public CancelAction()
        {
            super("Cancel");
        }

        public void actionPerformed(ActionEvent e)
        {
            dialogWrapper.dispose();
        }
    }

}