/*
 * Copyright (C) 2002-2005 Stefan Stiller
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package com.kiwisoft.utils.gui.action;

import java.awt.event.MouseListener;
import java.awt.event.MouseEvent;
import java.awt.event.ActionEvent;
import javax.swing.text.JTextComponent;
import javax.swing.JComponent;
import javax.swing.JPopupMenu;
import javax.swing.AbstractAction;
import javax.swing.JMenu;

import com.kiwisoft.utils.Disposable;

/**
 * @author Stefan Stiller
 * @version $Revision: 1.3 $, $Date: 2005/08/10 18:55:15 $
 */
public class ContextMenu implements MouseListener
{
	private JComponent component;
	private ContextAction[] actions;

	public ContextMenu(JTextComponent component, ContextAction[] actions)
	{
		assert component!=null;
		assert actions!=null;
		this.component=component;
		this.actions=actions;
	}

	public Disposable install()
	{
		component.addMouseListener(this);
		return new Disposable()
		{
			public void dispose()
			{
				component.removeMouseListener(ContextMenu.this);
			}
		};
	}

	public void mouseClicked(MouseEvent e)
	{
		if (e.isPopupTrigger())
		{
			ActionContext context=createContext();
			JPopupMenu menu=new JPopupMenu();
			boolean separator=false;
			for (int i=0; i<actions.length; i++)
			{
				ContextAction action=actions[i];
				if (action==null) separator=true;
				else
				{
					boolean enabled=action.isEnabled(context);
					if (enabled || !action.isHideDisabled())
					{
						if (separator && menu.getComponentCount()>0)
						{
							menu.addSeparator();
							separator=false;
						}
						ContextAction[] subActions=action.getSubActions();
						if (subActions==null) menu.add(new ContextActionWrapper(context, action));
						else
						{
							JMenu subMenu=new JMenu(new ContextActionWrapper(context, action));
							addMenuActions(subMenu, subActions, context);
							menu.add(subMenu);
						}
					}
				}
			}
		}
	}

	private void addMenuActions(JMenu menu, ContextAction[] actions, ActionContext context)
	{
		boolean separator=false;
		for (int i=0; i<actions.length; i++)
		{
			ContextAction action=actions[i];
			if (action==null) separator=true;
			else
			{
				boolean enabled=action.isEnabled(context);
				if (enabled || !action.isHideDisabled())
				{
					if (separator && menu.getComponentCount()>0)
					{
						menu.addSeparator();
						separator=false;
					}
					ContextAction[] subActions=action.getSubActions();
					if (subActions==null) menu.add(new ContextActionWrapper(context, action));
					else
					{
						JMenu subMenu=new JMenu(new ContextActionWrapper(context, action));
						addMenuActions(subMenu, subActions, context);
						menu.add(subMenu);
					}
				}
			}
		}
	}

	private static class ContextActionWrapper extends AbstractAction
	{
		private ActionContext context;
		private ContextAction action;

		public ContextActionWrapper(ActionContext context, ContextAction action)
		{
			putValue(NAME, action.getName());
			putValue(SMALL_ICON, action.getIcon());
			putValue(SHORT_DESCRIPTION, action.getDescription());
			this.context=context;
			this.action=action;
		}

		public void actionPerformed(ActionEvent e)
		{
			action.perform(context, e);
		}
	}

	private ActionContext createContext()
	{
		if (component instanceof JTextComponent)
			return new TextFieldActionContext((JTextComponent)component);
		else
			throw new UnsupportedOperationException("Component type not supported: "+component.getClass());
	}

	public void mouseEntered(MouseEvent e)
	{
	}

	public void mouseExited(MouseEvent e)
	{
	}

	public void mousePressed(MouseEvent e)
	{
	}

	public void mouseReleased(MouseEvent e)
	{
	}
}
