/*
 * Copyright (C) 2002-2005 Stefan Stiller
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package com.kiwisoft.utils.gui.table;

import java.awt.Color;
import java.awt.Font;
import java.util.Date;
import javax.swing.*;

import com.kiwisoft.utils.gui.ObjectStyle;
import com.kiwisoft.utils.gui.StrikeThroughDecorator;
import com.kiwisoft.utils.Tristate;
import com.kiwisoft.utils.format.ObjectFormat;
import com.kiwisoft.utils.format.ByteArrayFormat;

/**
 * @author Stefan Stiller
 * @version $Revision: 1.3 $, $Date: 2005/08/10 18:55:29 $
 */
public class TableTest
{
	private TableTest()
	{
	}

	public static void main(String[] args)
	{
		RendererFactory.getInstance().setRenderer(byte[].class, new ByteArrayFormat(ObjectFormat.DEFAULT));


		TestModel model=new TestModel();
		model.addRow(new TestRow("String", "abcde"));
		model.addRow(new TestRow("Integer", new Integer(12345)));
		model.addRow(new TestRow("Double", new Double(123.45)));
		model.addRow(new TestRow("Boolean", Boolean.TRUE));
		model.addRow(new TestRow("Tristate", Tristate.FALSE));
		model.addRow(new TestRow("Date", new Date()));
		model.addRow(new TestRow("byte[]", new byte[]{1, 2, 3, 4}));

		SortableTable table=new SortableTable(model);

		JFrame frame=new JFrame();
		frame.setContentPane(new JScrollPane(table));
		frame.setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);
		frame.pack();
		frame.setVisible(true);
	}

	private static class TestModel extends SortableTableModel
	{
		private ObjectStyle[] styles;

		public TestModel()
		{
			styles=new ObjectStyle[]
			{
				null,
				null,
				new ObjectStyle(null, Color.GREEN),
				new ObjectStyle(Color.RED, null),
				new ObjectStyle(UIManager.getFont("Label.font").deriveFont(Font.BOLD)),
				new ObjectStyle(new StrikeThroughDecorator(Color.RED)),
				new ObjectStyle(Color.BLUE, Color.LIGHT_GRAY, new StrikeThroughDecorator())
			};
		}

		public int getColumnCount()
		{
			return styles.length;
		}

		public ObjectStyle getCellStyle(int row, int col)
		{
			return styles[col];
		}
	}

	private static class TestRow extends SortableTableRow
	{
		private String name;

		public TestRow(String name, Object userObject)
		{
			super(userObject);
			this.name=name;
		}

		public Object getDisplayValue(int column)
		{
			if (column==0) return name;
			return getUserObject();
		}

		public boolean isEditable(int column)
		{
			return column>0;
		}

		public int setValue(Object value, int col)
		{
			if (col>0)
			{
				setUserObject(value);
				return SortableTableModel.ROW_UPDATE;
			}
			return SortableTableModel.NO_UPDATE;
		}
	}
}
