/*
 * Copyright (C) 2002-2005 Stefan Stiller
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package com.kiwisoft.utils.xml;

import java.io.*;
import java.util.Stack;

/**
 * @author Stefan Stiller
 * @version $Revision: 1.2 $, $Date: 2005/08/10 18:56:08 $
 */
public class XMLWriter
{
	private Writer writer;
	private Stack tags;
	private boolean tagOpen;
	private boolean started;
	private String encoding;

	public XMLWriter(OutputStream outputStream, String encoding)
	{
		writer=new OutputStreamWriter(outputStream);
		this.encoding=encoding;
		tags=new Stack();
	}

	public XMLWriter(Writer writer, String encoding)
	{
		this.writer=writer;
		this.encoding=encoding;
		tags=new Stack();
	}

	public void start() throws IOException
	{
		if (!started)
		{
			writer.write("<?xml version=\"1.0\"");
			if (encoding!=null) writer.write(" encoding=\""+encoding+"\"");
			writer.write(" ?>\n");
			started=true;
		}
	}

	public void startElement(String name) throws IOException
	{
		if (!started) throw new RuntimeException("Writer not opened");
		if (!XMLUtils.isXMLName(name)) throw new RuntimeException("Invalid tag name: "+name);
		if (tagOpen) writer.write(">\n");
		printIndent();
		writer.write("<"+name);
		tags.push(name);
		tagOpen=true;
	}

	public void setAttribute(String name, String value) throws IOException
	{
		if (!tagOpen) throw new RuntimeException("Tag already closed");
		if (!XMLUtils.isXMLName(name)) throw new RuntimeException("Invalid attribute name: "+name);
		if (value!=null) writer.write(" "+name+"=\""+XMLUtils.toXMLString(value)+"\"");
	}

	public void closeElement(String name) throws IOException
	{
		Object tag=tags.pop();
		if (!name.equals(tag)) throw new RuntimeException("Tag stack error");
		if (tagOpen)
			writer.write("/>\n");
		else
		{
			printIndent();
			writer.write("</"+name+">\n");
		}
		tagOpen=false;
	}

	public void close() throws IOException
	{
		if (!tags.isEmpty()) throw new RuntimeException("Not all elements have been closed");
		started=false;
		writer.flush();
		writer.close();
	}

	private void printIndent() throws IOException
	{
		for (int i=0; i<tags.size(); i++) writer.write("\t");
	}
}
